@@ -1,7 +1,7 @@
 __author__ = 'Rens Holmer'
-__version__ = '0.0.14'
+__version__ = '0.0.15'
 
-from .tree import Tree  # noqa
+from .tree import Tree, treeplot  # noqa
 from .sequence import (  # noqa
     Alphabet,
     alphabets,
